"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_spec_1 = require("./index.spec");
const collection_1 = __importDefault(require("./collection"));
class TestCollectionBase extends collection_1.default {
}
class TestBaseWithCollection extends index_spec_1.TestEntity {
    static createWithCollection(text1, text2, tests) {
        const instance = index_spec_1.TestEntity.reconstruct(text1, text2);
        instance.tests = tests;
        return instance;
    }
}
describe('Entity CollectionBase', () => {
    describe('validate', () => {
        it('should not throw error', () => {
            expect(TestCollectionBase.create([
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(1), index_spec_1.TestText.create('1')),
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(2), index_spec_1.TestText.create('2')),
            ]).validate()).toBeUndefined();
        });
        it('should return validation errors', () => {
            const errors = TestCollectionBase.create([
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(1), index_spec_1.TestText.create('1')),
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(2), index_spec_1.TestText.create('')),
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(''), index_spec_1.TestText.create('')),
            ]).validate();
            expect(errors).not.toBeUndefined();
            expect(errors).toEqual({
                'text1[2]': ['値を指定してください'],
                'text2[1]': ['値を指定してください'],
                'text2[2]': ['値を指定してください'],
            });
        });
    });
    it('should throw error if call constructor directory', () => {
        expect(() => new TestCollectionBase([])).toThrow();
    });
    describe('iterator', () => {
        it('should be iterable', () => {
            const items = [];
            for (const item of TestCollectionBase.create([
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(1), index_spec_1.TestText.create('2')),
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(3), index_spec_1.TestText.create('4')),
            ])) {
                items.push([item.text1.value, item.text2.value]);
            }
            expect(items).toEqual([
                ['1', '2'],
                ['3', '4'],
            ]);
        });
    });
    describe('isEmpty', () => {
        it('should return true if empty', () => {
            expect(TestCollectionBase.create([]).isEmpty()).toBe(true);
        });
        it('should return false if not empty', () => {
            expect(TestCollectionBase.create([index_spec_1.TestEntity.create(index_spec_1.TestText.create(1), index_spec_1.TestText.create('1'))]).isEmpty()).toBe(false);
        });
    });
});
describe('Entity with collection', () => {
    describe('getErrors', () => {
        it('should return empty', () => {
            expect(TestBaseWithCollection.createWithCollection(index_spec_1.TestText.create(1), index_spec_1.TestText.create('1'), TestCollectionBase.create([])).getErrors()).toEqual({});
        });
        it('should return validation errors', () => {
            const errors = TestBaseWithCollection.createWithCollection(index_spec_1.TestText.create(''), index_spec_1.TestText.create(''), TestCollectionBase.create([
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(1), index_spec_1.TestText.create('1')),
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(2), index_spec_1.TestText.create('')),
                index_spec_1.TestEntity.reconstruct(index_spec_1.TestText.create(''), index_spec_1.TestText.create('')),
            ])).getErrors();
            expect(errors).not.toBeUndefined();
            expect(errors).toEqual({
                text1: ['値を指定してください'],
                'text1[2]': ['値を指定してください'],
                text2: ['値を指定してください'],
                'text2[1]': ['値を指定してください'],
                'text2[2]': ['値を指定してください'],
            });
        });
    });
});
//# sourceMappingURL=collection.spec.js.map